pub struct BucketFileStats {
pub mean: f64,
pub median: f64,
pub stdev: f64,
pub min: f64,
pub max: f64,
}Expand description
Per-bucket statistics about total sequence lengths of source files.
Each source file contributes one “file length” — the sum of all sequence bases in that file. These stats summarize the distribution of file lengths within a single bucket.
Fields
mean: f64Mean of per-file total sequence lengths.
median: f64Median of per-file total sequence lengths.
stdev: f64Population standard deviation of per-file total sequence lengths.
min: f64Minimum per-file total sequence length.
max: f64Maximum per-file total sequence length.
Implementations
Sourceimpl BucketFileStats
impl BucketFileStats
Sourcepub fn from_file_lengths(lengths: &[u64]) -> Option<Self>
pub fn from_file_lengths(lengths: &[u64]) -> Option<Self>
Compute stats from a slice of per-file total sequence lengths.
Returns None if the slice is empty.